@@ -16,9 +16,8 @@ def name(count: Optional[int] = None,
             will be generated. Defaults to `None`
 
     Returns:
-        str: A random first name if `count` is `None`
-        list of str: A list of random first names
-            if `count` is not `None`
+        Union[str, List[str]]: A random first name if `count` is `None`
+            or a list of random first names if `count` is not `None`
     '''
     if gender == 'm':
         names = get_data('names', 'male_names')
@@ -44,8 +43,8 @@ def surname(count: Optional[int] = None) -> Union[str, List[str]]:
             generated. Defaults to `None`
 
     Returns:
-        str: A random surname if `count` is `None`
-        list of str: A list of surnames if `count` is not `None`
+        Union[str, List[str]]: A random surname if `count` is `None`
+            or a list of surnames if `count` is not `None`
     '''
     surnames = get_data('names', 'surnames')
 
@@ -67,9 +66,8 @@ def fullname(count: Optional[int] = None,
             will be generated. Defaults to `None`
 
     Returns:
-        str: A random fullname if `count` is `None`
-        list of str: A list of random fullnames
-            if `count` is not `None`
+        Union[str, List[str]]: A random fullname if `count` is `None`
+            or a list of random fullnames if `count` is not `None`
     '''
     if gender == 'm':
         names = get_data('names', 'male_names')
